@@ -86,15 +86,6 @@ class Connector(object):
         """Close this connector and the associated HTTP session."""
         self._session.close()
 
-    def check_retry_on_exception(self, exception_msg):
-        """Checks whether retry on exception is required."""
-        if ('SYS518' in str(exception_msg)):
-            LOG.debug('iDRAC is not yet ready after previous operation. '
-                      'Error: %(err)s', {'err': str(exception_msg)})
-            return True
-        else:
-            return False
-
     def _op(self, method, path='', data=None, headers=None, blocking=False,
             timeout=60, server_side_retries=_SERVER_SIDE_RETRIES,
             **extra_session_req_kwargs):
@@ -208,9 +199,9 @@ class Connector(object):
                               "%s", e.message)
                 raise
         except exceptions.ServerSideError as e:
-            if ((method.lower() == 'get'
-                or self.check_retry_on_exception(e.message))
-                    and server_side_retries > 0):
+            if method.lower() != 'get' or server_side_retries <= 0:
+                raise
+            else:
                 LOG.warning('Got server side error %s in response to a '
                             'GET request, retrying after %d seconds',
                             e, _SERVER_SIDE_RETRY_DELAY)
@@ -219,8 +210,6 @@ class Connector(object):
                                 blocking=blocking, timeout=timeout,
                                 server_side_retries=server_side_retries - 1,
                                 **extra_session_req_kwargs)
-            else:
-                raise
 
         if blocking and response.status_code == 202:
             if not response.headers.get('Location'):
