@@ -14,6 +14,7 @@
 #    under the License.
 import collections
 import logging
+import os
 
 import pkg_resources
 import requests
@@ -22,8 +23,10 @@ from sushy import auth as sushy_auth
 from sushy import connector as sushy_connector
 from sushy import exceptions
 from sushy.resources import base
+from sushy.resources.certificateservice import certificateservice
 from sushy.resources.chassis import chassis
 from sushy.resources.compositionservice import compositionservice
+from sushy.resources.eventservice import eventservice
 from sushy.resources.fabric import fabric
 from sushy.resources.manager import manager
 from sushy.resources.registry import message_registry
@@ -31,7 +34,9 @@ from sushy.resources.registry import message_registry_file
 from sushy.resources.sessionservice import session
 from sushy.resources.sessionservice import sessionservice
 from sushy.resources.system import system
+from sushy.resources.taskservice import taskservice
 from sushy.resources.updateservice import updateservice
+from sushy import taskmonitor
 from sushy import utils
 
 LOG = logging.getLogger(__name__)
@@ -143,6 +148,12 @@ class Sushy(base.ResourceBase):
     _update_service_path = base.Field(['UpdateService', '@odata.id'])
     """UpdateService path"""
 
+    _event_service_path = base.Field(['EventService', '@odata.id'])
+    """EventService path"""
+
+    _certificate_service_path = base.Field(['CertificateService', '@odata.id'])
+    """CertificateService path"""
+
     def __init__(self, base_url, username=None, password=None,
                  root_prefix='/redfish/v1/', verify=True,
                  auth=None, connector=None,
@@ -225,7 +236,7 @@ class Sushy(base.ResourceBase):
         return system.SystemCollection(
             self._conn, self._systems_path,
             redfish_version=self.redfish_version,
-            registries=self.lazy_registries)
+            registries=self.lazy_registries, root=self)
 
     def get_system(self, identity=None):
         """Given the identity return a System object
@@ -248,7 +259,7 @@ class Sushy(base.ResourceBase):
 
         return system.System(self._conn, identity,
                              redfish_version=self.redfish_version,
-                             registries=self.lazy_registries)
+                             registries=self.lazy_registries, root=self)
 
     def get_chassis_collection(self):
         """Get the ChassisCollection object
@@ -263,7 +274,8 @@ class Sushy(base.ResourceBase):
 
         return chassis.ChassisCollection(self._conn, self._chassis_path,
                                          redfish_version=self.redfish_version,
-                                         registries=self.lazy_registries)
+                                         registries=self.lazy_registries,
+                                         root=self)
 
     def get_chassis(self, identity=None):
         """Given the identity return a Chassis object
@@ -286,7 +298,7 @@ class Sushy(base.ResourceBase):
 
         return chassis.Chassis(self._conn, identity,
                                redfish_version=self.redfish_version,
-                               registries=self.lazy_registries)
+                               registries=self.lazy_registries, root=self)
 
     def get_fabric_collection(self):
         """Get the FabricCollection object
@@ -301,7 +313,8 @@ class Sushy(base.ResourceBase):
 
         return fabric.FabricCollection(self._conn, self._fabrics_path,
                                        redfish_version=self.redfish_version,
-                                       registries=self.lazy_registries)
+                                       registries=self.lazy_registries,
+                                       root=self)
 
     def get_fabric(self, identity):
         """Given the identity return a Fabric object
@@ -311,7 +324,7 @@ class Sushy(base.ResourceBase):
         """
         return fabric.Fabric(self._conn, identity,
                              redfish_version=self.redfish_version,
-                             registries=self.lazy_registries)
+                             registries=self.lazy_registries, root=self)
 
     def get_manager_collection(self):
         """Get the ManagerCollection object
@@ -326,7 +339,8 @@ class Sushy(base.ResourceBase):
 
         return manager.ManagerCollection(self._conn, self._managers_path,
                                          redfish_version=self.redfish_version,
-                                         registries=self.lazy_registries)
+                                         registries=self.lazy_registries,
+                                         root=self)
 
     def get_manager(self, identity=None):
         """Given the identity return a Manager object
@@ -348,7 +362,7 @@ class Sushy(base.ResourceBase):
 
         return manager.Manager(self._conn, identity,
                                redfish_version=self.redfish_version,
-                               registries=self.lazy_registries)
+                               registries=self.lazy_registries, root=self)
 
     def get_session_service(self):
         """Get the SessionService object
@@ -363,14 +377,19 @@ class Sushy(base.ResourceBase):
 
         return sessionservice.SessionService(
             self._conn, self._session_service_path,
-            redfish_version=self.redfish_version)
+            redfish_version=self.redfish_version, root=self)
 
     def get_sessions_path(self):
         """Returns the Sessions url"""
-
+        # NOTE(TheJulia): This method is the standard discovery method
+        # advised by the DMTF DSP0266 standard to find the session service.
         try:
             links_url = self.json.get('Links')
-            return links_url['Sessions']['@odata.id']
+            sessions_uri = links_url['Sessions']['@odata.id']
+            # Save the session URL for post detection and prevention
+            # of recursive autentication attempts.
+            self._conn._sessions_uri = sessions_uri
+            return sessions_uri
         except (TypeError, KeyError):
             raise exceptions.MissingAttributeError(
                 attribute='Links/Sessions/@data.id', resource=self.path)
@@ -384,7 +403,63 @@ class Sushy(base.ResourceBase):
         return session.Session(
             self._conn, identity,
             redfish_version=self.redfish_version,
-            registries=self.lazy_registries)
+            registries=self.lazy_registries, root=self)
+
+    def create_session(self, username=None, password=None):
+        """Creates a session without invoking SessionService.
+
+        For use when a new connection is to be established. Removes prior
+        Session and authentication data before making the request.
+
+        :param username: The username to utilize to create a session with the
+                         remote endpoint.
+        :param password: The password to utilize to create a session with the
+                         remote endpoint.
+        :returns: A session key and uri in the form of a tuple
+        :raises: MissingXAuthToken
+        :raises: ConnectionError
+        :raises: AccessError
+        :raises: HTTPError
+        :raises: MissingAttributeError
+        """
+        # Explicitly removes in-client session data to proceed. This prevents
+        # AccessErrors as prior authentication shouldn't be submitted with a
+        # new authentication attempt, and doing so with old/invalid session
+        # data can result in an AccessError being raised.
+        self._conn._session.auth = None
+        if 'X-Auth-Token' in self._conn._session.headers:
+            # Delete the token value that was saved to the session
+            # as otherwise we would end up with a dictionary containing
+            # a {'X-Auth-Token': null} being sent across to the remote
+            # bmc.
+            del self._conn._session.headers['X-Auth-Token']
+        try:
+            session_service_path = self.get_sessions_path()
+        except (exceptions.MissingAttributeError, exceptions.AccessError):
+            # Guesses path based upon DMTF standard, in the event
+            # the links resource on the service root is incorrect.
+            session_service_path = os.path.join(self._path,
+                                                'SessionService/Sessions')
+            LOG.warning('Could not discover the Session service path, '
+                        'falling back to %s.',
+                        session_service_path)
+            session_url = self._root_prefix + 'SessionService/Sessions'
+            self._conn._sessions_uri = session_url
+
+        data = {'UserName': username, 'Password': password}
+        LOG.debug("Requesting new session from %s.",
+                  session_service_path)
+        rsp = self._conn.post(session_service_path, data=data)
+        session_key = rsp.headers.get('X-Auth-Token')
+        if session_key is None:
+            raise exceptions.MissingXAuthToken(
+                method='POST', url=session_service_path, response=rsp)
+
+        session_uri = rsp.headers.get('Location')
+        if session_uri is None:
+            LOG.warning("Received X-Auth-Token but NO session uri.")
+
+        return session_key, session_uri
 
     def get_update_service(self):
         """Get the UpdateService object
@@ -398,7 +473,17 @@ class Sushy(base.ResourceBase):
         return updateservice.UpdateService(
             self._conn, self._update_service_path,
             redfish_version=self.redfish_version,
-            registries=self.lazy_registries)
+            registries=self.lazy_registries, root=self)
+
+    def get_task_service(self):
+        """Get the TaskService object
+
+        :returns: The TaskService object
+        """
+        return taskservice.TaskService(
+            self._conn, utils.get_sub_resource_path_by(self, 'Tasks'),
+            redfish_version=self.redfish_version,
+            registries=self.lazy_registries, root=self)
 
     def _get_registry_collection(self):
         """Get MessageRegistryFileCollection object
@@ -413,7 +498,7 @@ class Sushy(base.ResourceBase):
             return message_registry_file.MessageRegistryFileCollection(
                 self._conn,
                 self._registries_path,
-                redfish_version=self.redfish_version)
+                redfish_version=self.redfish_version, root=self)
 
     def get_composition_service(self):
         """Get the CompositionService object
@@ -430,7 +515,37 @@ class Sushy(base.ResourceBase):
         return compositionservice.CompositionService(
             self._conn, self._composition_service_path,
             redfish_version=self.redfish_version,
-            registries=self.lazy_registries)
+            registries=self.lazy_registries, root=self)
+
+    def get_certificate_service(self):
+        """Get the CertificateService object
+
+        :returns: The CertificateService object
+        """
+        if not self._certificate_service_path:
+            raise exceptions.MissingAttributeError(
+                attribute='CertificateService/@odata.id',
+                resource=self._path)
+
+        return certificateservice.CertificateService(
+            self._conn, self._certificate_service_path,
+            redfish_version=self.redfish_version,
+            registries=self.lazy_registries, root=self)
+
+    def get_event_service(self):
+        """Get the EventService object
+
+        :raises: MissingAttributeError, if the EventService is not found
+        :returns: The EventService object
+        """
+        if not self._event_service_path:
+            raise exceptions.MissingAttributeError(
+                attribute='EventService/@odata.id',
+                resource=self._path)
+        return eventservice.EventService(
+            self._conn, self._event_service_path,
+            redfish_version=self.redfish_version,
+            registries=self.lazy_registries, root=self)
 
     def _get_standard_message_registry_collection(self):
         """Load packaged standard message registries
@@ -454,14 +569,16 @@ class Sushy(base.ResourceBase):
     @property
     @utils.cache_it
     def registries(self):
-        """Gets and combines all message registries together
+        """Gets and combines all registries together
 
         Fetches all registries if any provided by Redfish service
         and combines together with packaged standard registries.
+        Both message and attribute registries are supported from
+        the Redfish service.
 
-        :returns: dict of combined message registries keyed by both the
+        :returns: dict of combined registries keyed by both the
             registry name (Registry_name.Major_version.Minor_version) and the
-            message registry file identity, with the value being the actual
+            registry file identity, with the value being the actual
             registry itself.
         """
         standard = self._get_standard_message_registry_collection()
@@ -472,15 +589,30 @@ class Sushy(base.ResourceBase):
 
         registry_col = self._get_registry_collection()
 
+        endpoint_registries = {}
         if registry_col:
             provided = registry_col.get_members()
             for r in provided:
-                message_registry = r.get_message_registry(
+
+                # Check for Message and Attribute registries
+                registry = r.get_message_registry(
                     self._language,
                     self._public_connector)
-                registries[r.registry] = message_registry
-                if r.identity not in registries:
-                    registries[r.identity] = message_registry
+                if not registry:
+                    registry = r.get_attribute_registry(
+                        self._language,
+                        self._public_connector)
+                if registry:
+                    endpoint_registries[r.registry] = registry
+                    endpoint_registries.setdefault(r.identity, registry)
+
+        if endpoint_registries:
+            LOG.debug('Found registries for %(id)s: %(reg)s',
+                      {'id': self.identity,
+                       'reg': ', '.join(endpoint_registries)})
+            registries.update(endpoint_registries)
+        else:
+            LOG.debug('No registries are available for %s', self.identity)
 
         return registries
 
@@ -496,3 +628,15 @@ class Sushy(base.ResourceBase):
             itself.
         """
         return LazyRegistries(self)
+
+    def get_task_monitor(self, task_monitor_uri):
+        """Used to retrieve a TaskMonitor by task monitor URI.
+
+        :param task_monitor_uri: Task monitor URI
+        :returns: A task monitor.
+        """
+        return taskmonitor.TaskMonitor(
+            self._conn,
+            task_monitor_uri,
+            redfish_version=self.redfish_version,
+            registries=self.registries)
