@@ -17,8 +17,10 @@ from http import client as http_client
 
 from sushy import exceptions
 from sushy.resources import base
+from sushy.resources.certificateservice import certificate
 from sushy.resources import common
-from sushy.resources.manager import mappings as mgr_maps
+from sushy.resources.manager import constants as mgr_cons
+from sushy import utils
 
 
 class ActionsField(base.CompositeField):
@@ -35,6 +37,15 @@ class VirtualMedia(base.ResourceBase):
     name = base.Field('Name', required=True)
     """The name of resource"""
 
+    connected_via = base.MappedField('ConnectedVia', mgr_cons.ConnectedVia)
+    """Current virtual media connection methods
+
+    Applet: Connected to a client application
+    NotConnected: No current connection
+    Oem: Connected via an OEM-defined method
+    URI: Connected to a URI location
+    """
+
     image = base.Field('Image')
     """A URI providing the location of the selected image"""
 
@@ -44,29 +55,31 @@ class VirtualMedia(base.ResourceBase):
     inserted = base.Field('Inserted')
     """Indicates if virtual media is inserted in the virtual device"""
 
+    media_types = base.MappedListField(
+        'MediaTypes', mgr_cons.VirtualMediaType, default=[])
+    """List of supported media types as virtual media"""
+
+    status = common.StatusField('Status')
+    """The virtual media status"""
+
+    transfer_method = base.MappedField('TransferMethod',
+                                       mgr_cons.TransferMethod)
+    """The transfer method to use with the Image"""
+
+    user_name = base.Field('UserName')
+    """The user name to access the Image parameter-specified URI"""
+
+    verify_certificate = base.Field('VerifyCertificate', adapter=bool)
+    """Whether to verify the certificate of the server for the Image"""
+
     write_protected = base.Field('WriteProtected')
     """Indicates the media is write protected"""
 
-    media_types = base.Field(
-        'MediaTypes', adapter=(
-            lambda x: [mgr_maps.MEDIA_TYPE_VALUE_MAP[v] for v in x
-                       if v in mgr_maps.MEDIA_TYPE_VALUE_MAP]),
-        default=[])
-    """List of supported media types as virtual media"""
-
-    connected_via = base.MappedField('ConnectedVia',
-                                     mgr_maps.CONNECTED_VIA_VALUE_MAP)
-    """Current virtual media connection methods
-
-    Applet: Connected to a client application
-    NotConnected: No current connection
-    Oem: Connected via an OEM-defined method
-    URI: Connected to a URI location
-    """
-
     _actions = ActionsField('Actions')
     """Insert/eject action for virtual media"""
 
+    _certificates_path = base.Field(['Certificates', '@odata.id'])
+
     def _get_insert_media_uri(self):
         insert_media = self._actions.insert_media if self._actions else None
         use_patch = False
@@ -105,13 +118,18 @@ class VirtualMedia(base.ResourceBase):
                 return True
         return False
 
-    def insert_media(self, image, inserted=True, write_protected=False):
+    def insert_media(self, image, inserted=True, write_protected=True,
+                     username=None, password=None, transfer_method=None):
         """Attach remote media to virtual media
 
         :param image: a URI providing the location of the selected image
         :param inserted: specify if the image is to be treated as inserted upon
             completion of the action.
         :param write_protected: indicates the media is write protected
+        :param username: User name for the image URI.
+        :param password: Password for the image URI.
+        :param transfer_method: Transfer method (stream or upload) to use
+            for the image.
         """
         target_uri, use_patch = self._get_insert_media_uri()
         # NOTE(janders) Inserted and WriteProtected attributes are optional
@@ -125,6 +143,20 @@ class VirtualMedia(base.ResourceBase):
         # as per the spec (True, True). We continue to set Inserted and
         # WriteProtected in payload if PATCH method is used.
         payload = {'Image': image}
+        if username is not None:
+            payload['UserName'] = username
+        if password is not None:
+            payload['Password'] = password
+        if transfer_method is not None:
+            try:
+                payload['TransferMethod'] = \
+                    mgr_cons.TransferMethod(transfer_method).value
+            except ValueError:
+                raise exceptions.InvalidParameterValueError(
+                    parameter='transfer_method',
+                    value=transfer_method,
+                    valid_values=', '.join(map(str, mgr_cons.TransferMethod)))
+
         if use_patch:
             payload['Inserted'] = inserted
             payload['WriteProtected'] = write_protected
@@ -185,6 +217,31 @@ class VirtualMedia(base.ResourceBase):
                 self._conn.post(target_uri, data={})
         self.invalidate()
 
+    def set_verify_certificate(self, verify_certificate):
+        """Enable or disable certificate validation."""
+        if not isinstance(verify_certificate, bool):
+            raise exceptions.InvalidParameterValueError(
+                parameter='verify_certificate', value=verify_certificate,
+                valid_values='boolean (True, False)')
+
+        self._conn.patch(self.path,
+                         data={'VerifyCertificate': verify_certificate})
+        self.invalidate()
+
+    @property
+    @utils.cache_it
+    def certificates(self):
+        """Get the collection of certificates for this device."""
+        if not self._certificates_path:
+            raise exceptions.MissingAttributeError(
+                attribute='Certificates/@odata.id',
+                resource=self._path)
+
+        return certificate.CertificateCollection(
+            self._conn, self._certificates_path,
+            redfish_version=self.redfish_version,
+            registries=self.registries, root=self.root)
+
 
 class VirtualMediaCollection(base.ResourceCollectionBase):
     """A collection of virtual media attached to a Manager"""
