@@ -19,7 +19,6 @@ import logging
 from sushy import exceptions
 from sushy.resources import base
 from sushy.resources import common
-from sushy.resources import constants as res_cons
 from sushy.resources import settings
 from sushy import utils
 
@@ -147,25 +146,9 @@ class Bios(base.ResourceBase):
             set by the system.
         """
         payload = {'Attributes': value}
-        if (not apply_time
-                and (maint_window_start_time or maint_window_duration)):
-            raise ValueError('"apply_time" missing when passing maintenance '
-                             'window settings')
-        if apply_time:
-            prop = '@Redfish.SettingsApplyTime'
-            payload[prop] = {
-                '@odata.type': '#Settings.v1_0_0.PreferredApplyTime',
-                'ApplyTime': res_cons.ApplyTime(apply_time).value,
-            }
-            if maint_window_start_time and not maint_window_duration:
-                raise ValueError('"maint_window_duration" missing')
-            if not maint_window_start_time and maint_window_duration:
-                raise ValueError('"maint_window_start_time" missing')
-            if maint_window_start_time and maint_window_duration:
-                payload[prop]['MaintenanceWindowStartTime'] =\
-                    maint_window_start_time.isoformat()
-                payload[prop]['MaintenanceWindowDurationInSeconds'] =\
-                    maint_window_duration
+        payload = utils.process_apply_time_input(
+            payload, apply_time, maint_window_start_time,
+            maint_window_duration)
         self._settings.commit(self._conn,
                               payload)
         utils.cache_clear(self, force_refresh=False,
@@ -252,24 +235,6 @@ class Bios(base.ResourceBase):
             Indicates language of registry to be used. Defaults to 'en'.
         :returns: the BIOS Attribute Registry
         """
-        registries = self._registries
-        for key, registry in registries.items():
-            # Check that BIOS attribute_registry matches the identity
-            # of a registry, and this is the requested language
-            if (registry
-                    and self._attribute_registry in (key, registry.identity)):
-                if language != registry.language:
-                    LOG.debug('Found BIOS attribute registry but '
-                              'language %(lang)s does not match '
-                              '%(reg_lang)s',
-                              {'lang': language,
-                               'reg_lang': registry.language})
-                    continue
-
-                return registry
-
-        LOG.info('BIOS attribute registry %(registry)s '
-                 'not available for language %(lang)s',
-                 {'registry': self._attribute_registry,
-                  'lang': language})
-        return None
+        return self._get_registry(self._attribute_registry,
+                                  language=language,
+                                  description='BIOS attribute registry')
