@@ -23,13 +23,12 @@ from sushy import exceptions
 from sushy.resources import base
 from sushy.resources.chassis import chassis
 from sushy.resources import common
+from sushy.resources import constants as res_cons
 from sushy.resources.manager import manager
-from sushy.resources import mappings as res_maps
 from sushy.resources import settings
 from sushy.resources.system import bios
 from sushy.resources.system import constants as sys_cons
 from sushy.resources.system import ethernet_interface
-from sushy.resources.system import mappings as sys_maps
 from sushy.resources.system import processor
 from sushy.resources.system import secure_boot
 from sushy.resources.system import simple_storage as sys_simple_storage
@@ -50,13 +49,12 @@ class BootField(base.CompositeField):
         adapter=list)
 
     enabled = base.MappedField('BootSourceOverrideEnabled',
-                               sys_maps.BOOT_SOURCE_ENABLED_MAP)
+                               sys_cons.BootSourceOverrideEnabled)
 
     mode = base.MappedField('BootSourceOverrideMode',
-                            sys_maps.BOOT_SOURCE_MODE_MAP)
+                            sys_cons.BootSourceOverrideMode)
 
-    target = base.MappedField('BootSourceOverrideTarget',
-                              sys_maps.BOOT_SOURCE_TARGET_MAP)
+    target = base.MappedField('BootSourceOverrideTarget', sys_cons.BootSource)
 
 
 class MemorySummaryField(base.CompositeField):
@@ -94,8 +92,7 @@ class System(base.ResourceBase):
     identity = base.Field('Id', required=True)
     """The system identity string"""
 
-    indicator_led = base.MappedField('IndicatorLED',
-                                     res_maps.INDICATOR_LED_VALUE_MAP)
+    indicator_led = base.MappedField('IndicatorLED', res_cons.IndicatorLED)
     """Whether the indicator LED is lit or off"""
 
     manufacturer = base.Field('Manufacturer')
@@ -107,8 +104,7 @@ class System(base.ResourceBase):
     part_number = base.Field('PartNumber')
     """The system part number"""
 
-    power_state = base.MappedField('PowerState',
-                                   res_maps.POWER_STATE_VALUE_MAP)
+    power_state = base.MappedField('PowerState', res_cons.PowerState)
     """The system power state"""
 
     serial_number = base.Field('SerialNumber')
@@ -120,8 +116,7 @@ class System(base.ResourceBase):
     status = common.StatusField('Status')
     """The system status"""
 
-    system_type = base.MappedField('SystemType',
-                                   sys_maps.SYSTEM_TYPE_VALUE_MAP)
+    system_type = base.MappedField('SystemType', sys_cons.SystemType)
     """The system type"""
 
     uuid = base.Field('UUID')
@@ -179,11 +174,10 @@ class System(base.ResourceBase):
         if not reset_action.allowed_values:
             LOG.warning('Could not figure out the allowed values for the '
                         'reset system action for System %s', self.identity)
-            return set(sys_maps.RESET_SYSTEM_VALUE_MAP_REV)
+            return set(res_cons.ResetType)
 
-        return set([sys_maps.RESET_SYSTEM_VALUE_MAP[v] for v in
-                    set(sys_maps.RESET_SYSTEM_VALUE_MAP).
-                    intersection(reset_action.allowed_values)])
+        return {v for v in res_cons.ResetType
+                if v.value in reset_action.allowed_values}
 
     def reset_system(self, value):
         """Reset the system.
@@ -197,7 +191,7 @@ class System(base.ResourceBase):
             raise exceptions.InvalidParameterValueError(
                 parameter='value', value=value, valid_values=valid_resets)
 
-        value = sys_maps.RESET_SYSTEM_VALUE_MAP_REV[value]
+        value = res_cons.ResetType(value).value
         target_uri = self._get_reset_action_element().target_uri
 
         # TODO(lucasagomes): Check the return code and response body ?
@@ -213,11 +207,10 @@ class System(base.ResourceBase):
             LOG.warning('Could not figure out the allowed values for '
                         'configuring the boot source for System %s',
                         self.identity)
-            return set(sys_maps.BOOT_SOURCE_TARGET_MAP_REV)
+            return set(sys_cons.BootSource)
 
-        return set([sys_maps.BOOT_SOURCE_TARGET_MAP[v] for v in
-                    set(sys_maps.BOOT_SOURCE_TARGET_MAP).
-                    intersection(self.boot.allowed_values)])
+        return {v for v in sys_cons.BootSource
+                if v.value in self.boot.allowed_values}
 
     def set_system_boot_options(self, target=None, enabled=None, mode=None):
         """Set boot source and/or boot frequency and/or boot mode.
@@ -225,13 +218,12 @@ class System(base.ResourceBase):
         Set the boot source and/or boot frequency and/or boot mode to use
         on next reboot of the System.
 
-        :param target: The target boot source, optional.
-        :param enabled: The frequency, whether to set it for the next
-            reboot only (BOOT_SOURCE_ENABLED_ONCE) or persistent to all
-            future reboots (BOOT_SOURCE_ENABLED_CONTINUOUS) or disabled
-            (BOOT_SOURCE_ENABLED_DISABLED), optional.
-        :param mode: The boot mode (UEFI: BOOT_SOURCE_MODE_UEFI or
-            BIOS: BOOT_SOURCE_MODE_BIOS), optional.
+        :param target: The target boot source,
+            a :py:class:`sushy.BootSource` value. Optional.
+        :param enabled: How long the override be enabled,
+            a :py:class:`sushy.BootSourceOverrideEnabled` value. Optional.
+        :param mode: The boot mode,
+            a :py:class:`sushy.BootSourceOverrideMode` value. Optional.
         :raises: InvalidParameterValueError, if any information passed is
             invalid.
         """
@@ -251,7 +243,7 @@ class System(base.ResourceBase):
                     parameter='target', value=target,
                     valid_values=valid_targets)
 
-            fishy_target = sys_maps.BOOT_SOURCE_TARGET_MAP_REV[target]
+            target = sys_cons.BootSource(target)
             # NOTE(janders) on SuperMicro X11 and X12 machines, virtual media
             # is presented as an "USB CD" drive as opposed to a CD drive. Both
             # are present in the list of boot devices, however only selecting
@@ -261,33 +253,27 @@ class System(base.ResourceBase):
             # about to attempt boot from CD and overrides the boot device to
             # UsbCd instead which makes boot from vMedia work as expected.
             if (self.manufacturer and self.manufacturer.lower() == 'supermicro'
-                    and fishy_target == sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
-                        sys_cons.BOOT_SOURCE_TARGET_CD]
-                    and sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
-                        sys_cons.BOOT_SOURCE_TARGET_USB_CD]
+                    and target == sys_cons.BootSource.CD
+                    and sys_cons.BootSource.USB_CD.value
                     in self.boot.allowed_values):
-                fishy_target = sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
-                    sys_cons.BOOT_SOURCE_TARGET_USB_CD]
                 LOG.debug('Boot from vMedia was requested on a SuperMicro'
                           'machine. Overriding boot device from %s to %s.',
-                          sys_cons.BOOT_SOURCE_TARGET_CD,
-                          fishy_target)
-
+                          target, sys_cons.BootSource.USB_CD)
+                target = sys_cons.BootSource.USB_CD
             if (settings_resp and "BootSourceOverrideTarget" in
                     settings_boot_section):
                 settings_data['Boot']['BootSourceOverrideTarget'] = \
-                    fishy_target
+                    target.value
             else:
-                data['Boot']['BootSourceOverrideTarget'] = fishy_target
+                data['Boot']['BootSourceOverrideTarget'] = target.value
 
         if enabled is not None:
-            if enabled not in sys_maps.BOOT_SOURCE_ENABLED_MAP_REV:
+            try:
+                fishy_freq = sys_cons.BootSourceOverrideEnabled(enabled).value
+            except ValueError:
                 raise exceptions.InvalidParameterValueError(
                     parameter='enabled', value=enabled,
-                    valid_values=list(sys_maps.BOOT_SOURCE_ENABLED_MAP_REV))
-
-            fishy_freq = sys_maps.BOOT_SOURCE_ENABLED_MAP_REV[enabled]
-
+                    valid_values=list(sys_cons.BootSourceOverrideEnabled))
             if (settings_resp and "BootSourceOverrideEnabled" in
                     settings_boot_section):
                 settings_data['Boot']['BootSourceOverrideEnabled'] = fishy_freq
@@ -295,13 +281,12 @@ class System(base.ResourceBase):
                 data['Boot']['BootSourceOverrideEnabled'] = fishy_freq
 
         if mode is not None:
-            if mode not in sys_maps.BOOT_SOURCE_MODE_MAP_REV:
+            try:
+                fishy_mode = sys_cons.BootSourceOverrideMode(mode).value
+            except ValueError:
                 raise exceptions.InvalidParameterValueError(
                     parameter='mode', value=mode,
-                    valid_values=list(sys_maps.BOOT_SOURCE_MODE_MAP_REV))
-
-            fishy_mode = sys_maps.BOOT_SOURCE_MODE_MAP_REV[mode]
-
+                    valid_values=list(sys_cons.BootSourceOverrideMode))
             if (settings_resp and "BootSourceOverrideMode" in
                     settings_boot_section):
                 settings_data['Boot']['BootSourceOverrideMode'] = fishy_mode
@@ -322,7 +307,7 @@ class System(base.ResourceBase):
 
     # TODO(etingof): we should remove this method, eventually
     def set_system_boot_source(
-            self, target, enabled=sys_cons.BOOT_SOURCE_ENABLED_ONCE,
+            self, target, enabled=sys_cons.BootSourceOverrideEnabled.ONCE,
             mode=None):
         """Set boot source and/or boot frequency and/or boot mode.
 
@@ -331,14 +316,13 @@ class System(base.ResourceBase):
 
         This method is obsoleted by `set_system_boot_options`.
 
-        :param target: The target boot source.
+        :param target: The target boot source,
+            a :py:class:`sushy.BootSource` value.
         :param enabled: The frequency, whether to set it for the next
-            reboot only (BOOT_SOURCE_ENABLED_ONCE) or persistent to all
-            future reboots (BOOT_SOURCE_ENABLED_CONTINUOUS) or disabled
-            (BOOT_SOURCE_ENABLED_DISABLED).
-            Default is `BOOT_SOURCE_ENABLED_ONCE`.
-        :param mode: The boot mode (UEFI: BOOT_SOURCE_MODE_UEFI or
-            BIOS: BOOT_SOURCE_MODE_BIOS), optional.
+            a :py:class:`sushy.BootSourceOverrideEnabled` value.
+            Default is `ONCE`.
+        :param mode: The boot mode,
+            a :py:class:`sushy.BootSourceOverrideMode` value.
         :raises: InvalidParameterValueError, if any information passed is
             invalid.
         """
@@ -347,19 +331,18 @@ class System(base.ResourceBase):
     def set_indicator_led(self, state):
         """Set IndicatorLED to the given state.
 
-        :param state: Desired LED state, lit (INDICATOR_LED_LIT), blinking
-            (INDICATOR_LED_BLINKING), off (INDICATOR_LED_OFF)
+        :param state: Desired LED state, an IndicatorLED value.
         :raises: InvalidParameterValueError, if any information passed is
             invalid.
         """
-        if state not in res_maps.INDICATOR_LED_VALUE_MAP_REV:
+        try:
+            state = res_cons.IndicatorLED(state).value
+        except ValueError:
             raise exceptions.InvalidParameterValueError(
                 parameter='state', value=state,
-                valid_values=list(res_maps.INDICATOR_LED_VALUE_MAP_REV))
+                valid_values=' ,'.join(i.value for i in res_cons.IndicatorLED))
 
-        data = {
-            'IndicatorLED': res_maps.INDICATOR_LED_VALUE_MAP_REV[state]
-        }
+        data = {'IndicatorLED': state}
 
         self._conn.patch(self.path, data=data)
         self.invalidate()
