@@ -20,7 +20,6 @@ from sushy import exceptions
 from sushy.resources import base
 from sushy.resources import common
 from sushy.resources.updateservice import constants as up_cons
-from sushy.resources.updateservice import mappings as up_maps
 from sushy.resources.updateservice import softwareinventory
 from sushy import taskmonitor
 from sushy import utils
@@ -66,7 +65,7 @@ class UpdateService(base.ResourceBase):
     _software_inventory_path = base.Field(['SoftwareInventory', '@odata.id'])
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """A class representing a UpdateService
 
         :param connector: A Connector instance
@@ -75,9 +74,11 @@ class UpdateService(base.ResourceBase):
             the object according to schema of given version
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(UpdateService, self).__init__(
-            connector, identity, redfish_version, registries)
+            connector, identity, redfish_version=redfish_version,
+            registries=registries, root=root)
 
     def _get_simple_update_element(self):
         simple_update_action = self._actions.simple_update
@@ -95,7 +96,7 @@ class UpdateService(base.ResourceBase):
         LOG.warning(
             'Could not figure out the allowed values for the simple '
             'update action for UpdateService %s', self.identity)
-        return set(up_maps.TRANSFER_PROTOCOL_TYPE_VALUE_MAP)
+        return {x.value for x in up_cons.UpdateTransferProtocolType}
 
     def get_allowed_transfer_protocols(self):
         """Get the allowed values for transfer protocol.
@@ -110,7 +111,7 @@ class UpdateService(base.ResourceBase):
             LOG.debug(
                 'Server does not constrain allowed transfer protocols for '
                 'simple update action of UpdateService %s', self.identity)
-            return set(up_maps.TRANSFER_PROTOCOL_TYPE_VALUE_MAP_REV)
+            return set(up_cons.UpdateTransferProtocolType)
 
         return {simple_update_action.transfer_protocol}
 
@@ -123,8 +124,8 @@ class UpdateService(base.ResourceBase):
         valid_transfer_protocols = self.get_allowed_transfer_protocols()
 
         if transfer_protocol in valid_transfer_protocols:
-            transfer_protocol = up_maps.TRANSFER_PROTOCOL_TYPE_VALUE_MAP_REV[
-                transfer_protocol]
+            transfer_protocol = up_cons.UpdateTransferProtocolType(
+                transfer_protocol).value
 
         else:
             legacy_transfer_protocols = self._get_legacy_transfer_protocols()
@@ -137,7 +138,7 @@ class UpdateService(base.ResourceBase):
             LOG.warning(
                 'Legacy transfer protocol constant %s is being used. '
                 'Consider migrating to any of: %s', transfer_protocol,
-                ', '.join(up_maps.TRANSFER_PROTOCOL_TYPE_VALUE_MAP_REV))
+                ', '.join(x.value for x in up_cons.UpdateTransferProtocolType))
 
         target_uri = self._get_simple_update_element().target_uri
 
@@ -151,7 +152,8 @@ class UpdateService(base.ResourceBase):
         rsp = self._conn.post(target_uri, data=data)
 
         return taskmonitor.TaskMonitor.from_response(
-            self._conn, rsp, target_uri, self.redfish_version, self.registries)
+            self._conn, rsp, target_uri,
+            redfish_version=self.redfish_version, registries=self.registries)
 
     def get_task_monitor(self, task_monitor):
         """Used to retrieve a TaskMonitor.
@@ -163,7 +165,8 @@ class UpdateService(base.ResourceBase):
             self._conn,
             task_monitor,
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries,
+            root=self.root)
 
     @property
     @utils.cache_it
@@ -178,7 +181,7 @@ class UpdateService(base.ResourceBase):
             self._conn,
             self._software_inventory_path,
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
     @property
     @utils.cache_it
@@ -193,4 +196,4 @@ class UpdateService(base.ResourceBase):
             self._conn,
             self._firmware_inventory_path,
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
