@@ -39,7 +39,7 @@ class ResourceBlockTestCase(base.TestCase):
     def test__parse_attributes(self):
         self.res_block._parse_attributes(self.json_doc)
         self.assertEqual(
-            res_block_cons.COMPOSITION_STATE_COMPOSED,
+            res_block_cons.CompositionState.COMPOSED,
             self.res_block.composition_status.composition_state)
         self.assertEqual(1, self.res_block.composition_status.max_compositions)
         self.assertEqual(
@@ -51,12 +51,12 @@ class ResourceBlockTestCase(base.TestCase):
         self.assertEqual('DriveBlock3', self.res_block.identity)
         self.assertEqual('Drive Block 3', self.res_block.name)
         self.assertEqual(
-            res_block_cons.RESOURCE_BLOCK_TYPE_STORAGE,
+            res_block_cons.ResourceBlockType.STORAGE,
             self.res_block.resource_block_type)
         self.assertEqual(
-            res_cons.STATE_ENABLED,
+            res_cons.State.ENABLED,
             self.res_block.status.state)
-        self.assertEqual(res_cons.HEALTH_OK, self.res_block.status.health)
+        self.assertEqual(res_cons.Health.OK, self.res_block.status.health)
         exp_path = '/redfish/v1/CompositionService/ResourceBlocks/DriveBlock3'
         self.assertEqual(exp_path, self.res_block.path)
 
