@@ -44,10 +44,10 @@ class FabricTestCase(base.TestCase):
         self.assertEqual('SAS Fabric', self.fabric.name)
         self.assertEqual('A SAS Fabric with redundant switches.',
                          self.fabric.description)
-        self.assertEqual(sushy.PROTOCOL_TYPE_SAS,
+        self.assertEqual(sushy.Protocol.SAS,
                          self.fabric.fabric_type)
-        self.assertEqual(sushy.STATE_ENABLED, self.fabric.status.state)
-        self.assertEqual(sushy.HEALTH_OK, self.fabric.status.health)
+        self.assertEqual(sushy.State.ENABLED, self.fabric.status.state)
+        self.assertEqual(sushy.Health.OK, self.fabric.status.health)
 
     def test_endpoints(self):
         # | GIVEN |
@@ -74,7 +74,7 @@ class FabricTestCase(base.TestCase):
             '/redfish/v1/Fabrics/SAS/Endpoints/Drive1')
 
         self.assertEqual(member.name, "SAS Drive")
-        self.assertEqual(member.endpoint_protocol, sushy.PROTOCOL_TYPE_SAS)
+        self.assertEqual(member.endpoint_protocol, sushy.Protocol.SAS)
 
     def test_endpoints_on_refresh(self):
         # | GIVEN |
@@ -123,16 +123,19 @@ class FabricCollectionTestCase(base.TestCase):
         self.fabric.get_member('/redfish/v1/Fabrics/SAS1')
         fabric_mock.assert_called_once_with(
             self.fabric._conn, '/redfish/v1/Fabrics/SAS1',
-            self.fabric.redfish_version, None)
+            redfish_version=self.fabric.redfish_version, registries=None,
+            root=self.fabric.root)
 
     @mock.patch.object(fabric, 'Fabric', autospec=True)
     def test_get_members(self, fabric_mock):
         members = self.fabric.get_members()
         calls = [
             mock.call(self.fabric._conn, '/redfish/v1/Fabrics/SAS1',
-                      self.fabric.redfish_version, None),
+                      redfish_version=self.fabric.redfish_version,
+                      registries=None, root=self.fabric.root),
             mock.call(self.fabric._conn, '/redfish/v1/Fabrics/SAS2',
-                      self.fabric.redfish_version, None)
+                      redfish_version=self.fabric.redfish_version,
+                      registries=None, root=self.fabric.root)
         ]
         fabric_mock.assert_has_calls(calls)
         self.assertIsInstance(members, list)
