@@ -16,9 +16,12 @@ from http import client as http_client
 import json
 from unittest import mock
 
+import requests
 
 import sushy
 from sushy import exceptions
+from sushy.resources.certificateservice import certificate
+from sushy.resources.manager import constants as mgr_cons
 from sushy.resources.manager import virtual_media
 from sushy.tests.unit import base
 
@@ -48,10 +51,10 @@ class VirtualMediaTestCase(base.TestCase):
                          self.sys_virtual_media.image)
         self.assertEqual('Sardine2.1.43.35.6a',
                          self.sys_virtual_media.image_name)
-        self.assertEqual(sushy.CONNECTED_VIA_URI,
+        self.assertEqual(sushy.ConnectedVia.URI,
                          self.sys_virtual_media.connected_via)
-        self.assertEqual([sushy.VIRTUAL_MEDIA_FLOPPY,
-                          sushy.VIRTUAL_MEDIA_USBSTICK],
+        self.assertEqual([sushy.VirtualMediaType.FLOPPY,
+                          sushy.VirtualMediaType.USB_STICK],
                          self.sys_virtual_media.media_types)
         self.assertEqual(True, self.sys_virtual_media.inserted)
         self.assertEqual(False, self.sys_virtual_media.write_protected)
@@ -62,10 +65,10 @@ class VirtualMediaTestCase(base.TestCase):
         # Test that various types are returned correctly
         self.assertEqual('https://www.dmtf.org/freeImages/Sardine.img',
                          attributes.get('image'))
-        self.assertEqual(sushy.CONNECTED_VIA_URI,
+        self.assertEqual(sushy.ConnectedVia.URI,
                          attributes.get('connected_via'))
-        self.assertEqual([sushy.VIRTUAL_MEDIA_FLOPPY,
-                          sushy.VIRTUAL_MEDIA_USBSTICK],
+        self.assertEqual([sushy.VirtualMediaType.FLOPPY,
+                          sushy.VirtualMediaType.USB_STICK],
                          attributes.get('media_types'))
 
     def test_insert_media_none(self):
@@ -89,10 +92,54 @@ class VirtualMediaTestCase(base.TestCase):
             ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
              "/VirtualMedia.InsertMedia"),
             data={"Image": "https://www.dmtf.org/freeImages/Sardine.img",
-                  "Inserted": True, "WriteProtected": False}
+                  "WriteProtected": False}
         )
         self.assertTrue(self.sys_virtual_media._is_stale)
 
+    def test_insert_media_rf_default(self):
+        self.assertFalse(self.sys_virtual_media._is_stale)
+        self.sys_virtual_media.insert_media(
+            "https://www.dmtf.org/freeImages/Sardine.img", True, True)
+        self.sys_virtual_media._conn.post.assert_called_once_with(
+            ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
+             "/VirtualMedia.InsertMedia"),
+            data={"Image": "https://www.dmtf.org/freeImages/Sardine.img"}
+        )
+        self.assertTrue(self.sys_virtual_media._is_stale)
+
+    def test_insert_media_credentials(self):
+        self.assertFalse(self.sys_virtual_media._is_stale)
+        self.sys_virtual_media.insert_media(
+            "https://www.dmtf.org/freeImages/Sardine.img", True, False,
+            username="admin", password="pwd")
+        self.sys_virtual_media._conn.post.assert_called_once_with(
+            ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
+             "/VirtualMedia.InsertMedia"),
+            data={"Image": "https://www.dmtf.org/freeImages/Sardine.img",
+                  "WriteProtected": False,
+                  "UserName": "admin", "Password": "pwd"}
+        )
+        self.assertTrue(self.sys_virtual_media._is_stale)
+
+    def test_insert_media_transfer_method(self):
+        self.assertFalse(self.sys_virtual_media._is_stale)
+        self.sys_virtual_media.insert_media(
+            "https://www.dmtf.org/freeImages/Sardine.img", True, False,
+            transfer_method=mgr_cons.TransferMethod.UPLOAD)
+        self.sys_virtual_media._conn.post.assert_called_once_with(
+            ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
+             "/VirtualMedia.InsertMedia"),
+            data={"Image": "https://www.dmtf.org/freeImages/Sardine.img",
+                  "WriteProtected": False, "TransferMethod": "Upload"}
+        )
+        self.assertTrue(self.sys_virtual_media._is_stale)
+
+    def test_insert_media_transfer_method_wrong_input(self):
+        self.assertRaises(exceptions.InvalidParameterValueError,
+                          self.sys_virtual_media.insert_media,
+                          "https://www.dmtf.org/freeImages/Sardine.img",
+                          True, False, transfer_method='quickly!')
+
     def test_insert_media_fallback(self):
         self.conn.get.return_value.headers = {'Allow': 'GET,HEAD,PATCH'}
         self.sys_virtual_media._actions.insert_media = None
@@ -128,9 +175,23 @@ class VirtualMediaTestCase(base.TestCase):
             ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1"),
             data={"Image": "https://www.dmtf.org/freeImages/Sardine.img",
                   "Inserted": True, "WriteProtected": False},
-            headers={"If-Match": '"3d7b8a7360bf2941d"'})
+            headers={"If-Match": 'W/"3d7b8a7360bf2941d"'})
         self.assertTrue(self.sys_virtual_media._is_stale)
 
+    @mock.patch.object(requests, 'post', autospec=True)
+    def test_is_transfer_protocol_required(self, mock_post):
+        with open('sushy/tests/unit/json_samples/'
+                  'transfer_proto_required_error.json') as f:
+            response_obj = json.load(f)
+        response = mock.MagicMock()
+        response.status_code = 400
+        response.code = "Base.1.5.ActionParameterMissing"
+        response.body = response_obj['error']
+        response.raise_for_status.side_effect = requests.exceptions.HTTPError
+        mock_post.return_value = response
+        retval = self.sys_virtual_media.is_transfer_protocol_required(response)
+        self.assertTrue(retval)
+
     def test_eject_media_none(self):
         self.sys_virtual_media._actions.eject_media = None
         self.assertRaisesRegex(
@@ -178,7 +239,7 @@ class VirtualMediaTestCase(base.TestCase):
         self.sys_virtual_media._conn.patch.assert_called_once_with(
             ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1"),
             data={"Image": None, "Inserted": False},
-            headers={"If-Match": '"3d7b8a7360bf2941d"'})
+            headers={"If-Match": 'W/"3d7b8a7360bf2941d"'})
         self.assertTrue(self.sys_virtual_media._is_stale)
 
     def test_eject_media_pass_empty_dict_415(self):
@@ -206,3 +267,29 @@ class VirtualMediaTestCase(base.TestCase):
             mock.call(target_uri, data={})]
         self.sys_virtual_media._conn.post.assert_has_calls(post_calls)
         self.assertTrue(self.sys_virtual_media._is_stale)
+
+    def test_set_verify_certificate(self):
+        with mock.patch.object(
+                self.sys_virtual_media, 'invalidate',
+                autospec=True) as invalidate_mock:
+            self.sys_virtual_media.set_verify_certificate(True)
+            self.sys_virtual_media._conn.patch.assert_called_once_with(
+                "/redfish/v1/Managers/BMC/VirtualMedia/Floppy1",
+                data={'VerifyCertificate': True})
+
+            invalidate_mock.assert_called_once_with()
+
+    def test_set_verify_certificate_wrong_input(self):
+        self.assertRaises(exceptions.InvalidParameterValueError,
+                          self.sys_virtual_media.set_verify_certificate, 'yes')
+
+    @mock.patch.object(certificate, 'CertificateCollection', autospec=True)
+    def test_certificate_collection(self, mock_cert_coll):
+        result = self.sys_virtual_media.certificates
+        self.assertEqual(mock_cert_coll.return_value, result)
+        mock_cert_coll.assert_called_once_with(
+            self.conn,
+            "/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Certificates/",
+            redfish_version='1.0.2',
+            registries=self.sys_virtual_media.registries,
+            root=self.sys_virtual_media.root)
