@@ -46,23 +46,47 @@ class DriveTestCase(base.TestCase):
         self.assertIsInstance(identifiers, list)
         self.assertEqual(1, len(identifiers))
         identifier = identifiers[0]
-        self.assertEqual(sushy.DURABLE_NAME_FORMAT_NAA,
+        self.assertEqual(sushy.DurableNameFormat.NAA,
                          identifier.durable_name_format)
         self.assertEqual('32ADF365C6C1B7BD', identifier.durable_name)
         self.assertEqual('Contoso', self.stor_drive.manufacturer)
         self.assertEqual('HDD', self.stor_drive.media_type)
         self.assertEqual('C123', self.stor_drive.model)
         self.assertEqual('C123-1111', self.stor_drive.part_number)
-        self.assertEqual(sushy.PROTOCOL_TYPE_SAS, self.stor_drive.protocol)
+        self.assertEqual(sushy.Protocol.SAS, self.stor_drive.protocol)
         self.assertEqual('1234570', self.stor_drive.serial_number)
-        self.assertEqual(sushy.STATE_ENABLED, self.stor_drive.status.state)
-        self.assertEqual(sushy.HEALTH_OK, self.stor_drive.status.health)
+        self.assertEqual('100A', self.stor_drive.revision)
+        self.assertEqual(sushy.State.ENABLED, self.stor_drive.status.state)
+        self.assertEqual(sushy.Health.OK, self.stor_drive.status.health)
+
+    def test_volumes(self):
+        with open('sushy/tests/unit/json_samples/drive3.json') as f:
+            drive_json = json.load(f)
+        with open('sushy/tests/unit/json_samples/volume2.json') as f:
+            volume2_json = json.load(f)
+        with open('sushy/tests/unit/json_samples/volume3.json') as f:
+            volume3_json = json.load(f)
+
+        self.conn.get.return_value.json.side_effect = [drive_json,
+                                                       volume2_json,
+                                                       volume3_json]
+        stor_drive = drive.Drive(
+            self.conn,
+            '/redfish/v1/Systems/437XR1138R2/Storage/1/Drives/'
+            '3D58ECBC375FD9F2',
+            redfish_version='1.0.2')
+
+        volumes = stor_drive.volumes
+
+        self.assertEqual(2, len(volumes))
+        self.assertEqual('2', volumes[0].identity)
+        self.assertEqual('3', volumes[1].identity)
 
     def test_set_indicator_led(self):
         with mock.patch.object(
                 self.stor_drive, 'invalidate',
                 autospec=True) as invalidate_mock:
-            self.stor_drive.set_indicator_led(sushy.INDICATOR_LED_BLINKING)
+            self.stor_drive.set_indicator_led(sushy.IndicatorLED.BLINKING)
             self.stor_drive._conn.patch.assert_called_once_with(
                 '/redfish/v1/Systems/437XR1138/Storage/1/Drives/'
                 '32ADF365C6C1B7BD', data={'IndicatorLED': 'Blinking'})
