@@ -16,8 +16,10 @@ from unittest import mock
 from dateutil import parser
 
 import sushy
-from sushy import exceptions
+from sushy.resources import constants as res_cons
+from sushy.resources.system.storage import constants as store_cons
 from sushy.resources.system.storage import volume
+from sushy import taskmonitor
 from sushy.tests.unit import base
 
 
@@ -41,42 +43,68 @@ class VolumeTestCase(base.TestCase):
         self.assertEqual('1', self.stor_volume.identity)
         self.assertEqual('Virtual Disk 1', self.stor_volume.name)
         self.assertEqual(899527000000, self.stor_volume.capacity_bytes)
-        self.assertEqual(sushy.VOLUME_TYPE_MIRRORED,
+        self.assertEqual(sushy.VolumeType.MIRRORED,
                          self.stor_volume.volume_type)
         self.assertFalse(self.stor_volume.encrypted)
         identifiers = self.stor_volume.identifiers
         self.assertIsInstance(identifiers, list)
         self.assertEqual(1, len(identifiers))
         identifier = identifiers[0]
-        self.assertEqual(sushy.DURABLE_NAME_FORMAT_UUID,
+        self.assertEqual(sushy.DurableNameFormat.UUID,
                          identifier.durable_name_format)
         self.assertEqual('38f1818b-111e-463a-aa19-fa54f792e468',
                          identifier.durable_name)
         self.assertIsNone(self.stor_volume.block_size_bytes)
 
-    def test_initialize_volume(self):
+    def test_initialize_immediate(self):
         target_uri = '/redfish/v1/Systems/3/Storage/RAIDIntegrated/' \
                      'Volumes/1/Actions/Volume.Initialize'
-        self.stor_volume.initialize_volume('fast')
+        self.stor_volume.initialize(
+            store_cons.VolumeInitializeType.FAST,
+            apply_time=res_cons.ApplyTime.IMMEDIATE)
         self.stor_volume._conn.post.assert_called_once_with(
-            target_uri, data={'InitializeType': 'Fast'}, blocking=True)
+            target_uri, data={'InitializeType': 'Fast',
+                              '@Redfish.OperationApplyTime': 'Immediate'},
+            blocking=True, timeout=500)
 
-    def test_initialize_volume_bad_value(self):
-        self.assertRaisesRegex(
-            exceptions.InvalidParameterValueError,
-            'The parameter.*lazy.*invalid',
-            self.stor_volume.initialize_volume, 'lazy')
+    def test_initialize_on_reset(self):
+        target_uri = '/redfish/v1/Systems/3/Storage/RAIDIntegrated/' \
+                     'Volumes/1/Actions/Volume.Initialize'
+        self.stor_volume.initialize(
+            store_cons.VolumeInitializeType.SLOW,
+            apply_time=res_cons.ApplyTime.ON_RESET)
+        self.stor_volume._conn.post.assert_called_once_with(
+            target_uri, data={'InitializeType': 'Slow',
+                              '@Redfish.OperationApplyTime': 'OnReset'},
+            blocking=False, timeout=500)
 
-    def test_delete_volume(self):
-        self.stor_volume.delete_volume()
+    def test_delete_immediate(self):
+        payload = {}
+        self.conn.delete.return_value.status_code = 200
+        resource = self.stor_volume.delete(
+            payload=payload, apply_time=res_cons.ApplyTime.IMMEDIATE)
         self.stor_volume._conn.delete.assert_called_once_with(
-            self.stor_volume._path, data=None, blocking=True)
+            self.stor_volume._path, data=payload, blocking=True, timeout=500)
+        self.assertIsNone(resource)
 
-    def test_delete_volume_with_payload(self):
-        payload = {'@Redfish.OperationApplyTime': 'OnReset'}
-        self.stor_volume.delete_volume(payload=payload)
+    def test_delete_on_reset(self):
+        payload = {}
+        self.conn.delete.return_value.status_code = 202
+        self.conn.delete.return_value.headers = {
+            'Location': '/redfish/v1/taskmon/4608f7e6',
+            'Retry-After': '120'
+        }
+        self.conn.delete.return_value.json.return_value = {'Id': 3,
+                                                           'Name': 'Test'}
+        task_mon = self.stor_volume.delete(
+            payload=payload, apply_time=res_cons.ApplyTime.ON_RESET,
+            timeout=250)
         self.stor_volume._conn.delete.assert_called_once_with(
-            self.stor_volume._path, data=payload, blocking=True)
+            self.stor_volume._path, data=payload, blocking=False, timeout=250)
+        self.assertIsNotNone(task_mon)
+        self.assertIsInstance(task_mon, taskmonitor.TaskMonitor)
+        self.assertEqual(task_mon.task_monitor_uri,
+                         '/redfish/v1/taskmon/4608f7e6')
 
 
 class VolumeCollectionTestCase(base.TestCase):
@@ -113,6 +141,10 @@ class VolumeCollectionTestCase(base.TestCase):
                          support._maintenance_window_resource.resource_uri)
         self.assertEqual(['Immediate', 'OnReset', 'AtMaintenanceWindowStart'],
                          support.supported_values)
+        self.assertEqual([res_cons.ApplyTime.IMMEDIATE,
+                          res_cons.ApplyTime.ON_RESET,
+                          res_cons.ApplyTime.AT_MAINTENANCE_WINDOW_START],
+                         support.mapped_supported_values)
 
     @mock.patch.object(volume, 'Volume', autospec=True)
     def test_get_member(self, Volume_mock):
@@ -121,7 +153,8 @@ class VolumeCollectionTestCase(base.TestCase):
         Volume_mock.assert_called_once_with(
             self.stor_vol_col._conn,
             '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes/1',
-            self.stor_vol_col.redfish_version, None)
+            redfish_version=self.stor_vol_col.redfish_version, registries=None,
+            root=self.stor_vol_col.root)
 
     @mock.patch.object(volume, 'Volume', autospec=True)
     def test_get_members(self, Volume_mock):
@@ -129,13 +162,16 @@ class VolumeCollectionTestCase(base.TestCase):
         calls = [
             mock.call(self.stor_vol_col._conn,
                       '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes/1',
-                      self.stor_vol_col.redfish_version, None),
+                      redfish_version=self.stor_vol_col.redfish_version,
+                      registries=None, root=self.stor_vol_col.root),
             mock.call(self.stor_vol_col._conn,
                       '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes/2',
-                      self.stor_vol_col.redfish_version, None),
+                      redfish_version=self.stor_vol_col.redfish_version,
+                      registries=None, root=self.stor_vol_col.root),
             mock.call(self.stor_vol_col._conn,
                       '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes/3',
-                      self.stor_vol_col.redfish_version, None),
+                      redfish_version=self.stor_vol_col.redfish_version,
+                      registries=None, root=self.stor_vol_col.root),
         ]
         Volume_mock.assert_has_calls(calls)
         self.assertIsInstance(members, list)
@@ -175,27 +211,58 @@ class VolumeCollectionTestCase(base.TestCase):
 
         self.assertEqual(1073741824000, self.stor_vol_col.max_size_bytes)
 
-    def test_create_volume(self):
+    def test_create_immediate(self):
         payload = {
             'Name': 'My Volume 4',
             'VolumeType': 'Mirrored',
             'RAIDType': 'RAID1',
             'CapacityBytes': 107374182400
         }
+        expected_payload = dict(payload)
+        expected_payload['@Redfish.OperationApplyTime'] = 'Immediate'
         with open('sushy/tests/unit/json_samples/volume4.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         self.conn.post.return_value.status_code = 201
         self.conn.post.return_value.headers.return_value = {
             'Location': '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes/4'
         }
-        new_vol = self.stor_vol_col.create_volume(payload)
+        new_vol = self.stor_vol_col.create(
+            payload, apply_time=res_cons.ApplyTime.IMMEDIATE)
         self.stor_vol_col._conn.post.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes',
-            data=payload, blocking=True)
+            data=expected_payload, blocking=True, timeout=500)
         self.stor_vol_col.refresh.assert_called_once()
         self.assertIsNotNone(new_vol)
         self.assertEqual('4', new_vol.identity)
         self.assertEqual('My Volume 4', new_vol.name)
         self.assertEqual(107374182400, new_vol.capacity_bytes)
-        self.assertEqual(sushy.VOLUME_TYPE_MIRRORED, new_vol.volume_type)
-        self.assertEqual(sushy.RAID_TYPE_RAID1, new_vol.raid_type)
+        self.assertEqual(sushy.VolumeType.MIRRORED, new_vol.volume_type)
+        self.assertEqual(sushy.RAIDType.RAID1, new_vol.raid_type)
+
+    def test_create_on_reset(self):
+        payload = {
+            'Name': 'My Volume 4',
+            'VolumeType': 'Mirrored',
+            'RAIDType': 'RAID1',
+            'CapacityBytes': 107374182400
+        }
+        expected_payload = dict(payload)
+        expected_payload['@Redfish.OperationApplyTime'] = 'OnReset'
+        with open('sushy/tests/unit/json_samples/task.json') as f:
+            self.conn.post.return_value.json.return_value = json.load(f)
+
+        self.conn.post.return_value.content.return_value = "Something"
+        self.conn.post.return_value.status_code = 202
+        self.conn.post.return_value.headers = {
+            'Location': '/redfish/v1/taskmon/4608f7e6',
+            'Retry-After': '120'
+        }
+        task_mon = self.stor_vol_col.create(
+            payload, apply_time=res_cons.ApplyTime.ON_RESET)
+        self.stor_vol_col._conn.post.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2/Storage/1/Volumes',
+            data=expected_payload, blocking=False, timeout=500)
+        self.assertIsNotNone(task_mon)
+        self.assertIsInstance(task_mon, taskmonitor.TaskMonitor)
+        self.assertEqual(task_mon.task_monitor_uri,
+                         '/redfish/v1/TaskService/Tasks/545')
