@@ -14,6 +14,7 @@
 #    under the License.
 
 import copy
+import enum
 from http import client as http_client
 import io
 import json
@@ -40,7 +41,21 @@ BASE_RESOURCE_JSON = {
             "@odata.type": "http://AnotherStandardsBody/schemas.v1_0_1#styleInfoExt",  # noqa
             "Style": "Executive"
         }
+    },
+    "Links": {
+        "Oem": {
+            "Contoso": {
+                "@odata.type": "http://contoso.com/schemas/extensions.v1_2_1#contoso.AnvilTypes1",  # noqa
+                "slogan": "Contoso never fail",
+                "disclaimer": "* Most of the time"
+            },
+            "EID_420_ASB_345": {
+                "@odata.type": "http://AnotherStandardsBody/schemas.v1_0_1#styleInfoExt",  # noqa
+                "Style": "Executive"
+            }
+        }
     }
+
 }
 
 
@@ -139,8 +154,10 @@ class ResourceBaseTestCase(base.TestCase):
         self.assertIsNot(resource_a._reader, resource_b._reader)
 
     def test__parse_attributes(self):
-        for oem_vendor in self.base_resource2.oem_vendors:
-            self.assertTrue(oem_vendor in ('Contoso', 'EID_412_ASB_123'))
+        expected_oem_vendors = ['Contoso', 'EID_412_ASB_123',
+                                'EID_420_ASB_345']
+        actual_oem_vendors = sorted(self.base_resource2.oem_vendors)
+        self.assertEqual(expected_oem_vendors, actual_oem_vendors)
         self.assertEqual('base_resource2', self.base_resource2.resource_name)
 
     def test_refresh_local(self):
@@ -167,7 +184,7 @@ class TestResource(resource_base.ResourceBase):
     """A concrete Test Resource to test against"""
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """Ctor of TestResource
 
         :param connector: A Connector instance
@@ -178,7 +195,7 @@ class TestResource(resource_base.ResourceBase):
             used in any resource that needs registries to parse messages.
         """
         super(TestResource, self).__init__(connector, 'Fakes/%s' % identity,
-                                           redfish_version, registries)
+                                           redfish_version, registries, root)
         self.identity = identity
 
     def _parse_attributes(self, json_doc):
@@ -192,7 +209,8 @@ class TestResourceCollection(resource_base.ResourceCollectionBase):
     def _resource_type(self):
         return TestResource
 
-    def __init__(self, connector, redfish_version=None, registries=None):
+    def __init__(self, connector, redfish_version=None, registries=None,
+                 root=None):
         """Ctor of TestResourceCollection
 
         :param connector: A Connector instance
@@ -202,7 +220,7 @@ class TestResourceCollection(resource_base.ResourceCollectionBase):
             used in any resource that needs registries to parse messages.
         """
         super(TestResourceCollection, self).__init__(
-            connector, 'Fakes', redfish_version, registries)
+            connector, 'Fakes', redfish_version, registries, root)
 
 
 class ResourceCollectionBaseTestCase(base.TestCase):
@@ -247,7 +265,7 @@ class ResourceCollectionBaseTestCase(base.TestCase):
         self.assertIsInstance(result, list)
         for val in result:
             self.assertIsInstance(val, TestResource)
-            self.assertTrue(val.identity in member_ids)
+            self.assertIn(val.identity, member_ids)
             self.assertEqual('1.0.x', val.redfish_version)
             self.assertFalse(val._is_stale)
 
@@ -315,7 +333,9 @@ TEST_JSON = {
     'Dictionary': {
         'key1': {'property_a': 'value1', 'property_b': 'value2'},
         'key2': {'property_a': 'value3', 'property_b': 'value4'}
-    }
+    },
+    'Enum': 'PROTOCOL_FIELD_2',
+    'EnumList': ['PROTOCOL_FIELD_2', 'PROTOCOL_FIELD_3'],
 }
 
 
@@ -326,6 +346,13 @@ MAPPING = {
 }
 
 
+class EnumMapping(enum.Enum):
+
+    FIELD1 = "PROTOCOL_FIELD_1"
+    FIELD2 = "PROTOCOL_FIELD_2"
+    FIELD3 = "PROTOCOL_FIELD_3"
+
+
 class NestedTestField(resource_base.CompositeField):
     string = resource_base.Field('String', required=True)
     integer = resource_base.Field('Integer', adapter=int)
@@ -354,6 +381,10 @@ class ComplexResource(resource_base.ResourceBase):
     non_existing_nested = NestedTestField('NonExistingNested')
     non_existing_mapped = resource_base.MappedField('NonExistingMapped',
                                                     MAPPING)
+    enum_mapped = resource_base.MappedField('Enum', EnumMapping)
+    enum_mapped_list = resource_base.MappedListField('EnumList', EnumMapping)
+    non_existing_enum_mapped = resource_base.MappedField('NonExistingEnum',
+                                                         EnumMapping)
 
 
 class FieldTestCase(base.TestCase):
@@ -385,6 +416,10 @@ class FieldTestCase(base.TestCase):
                          self.test_resource.dictionary['key2'].property_b)
         self.assertIsNone(self.test_resource.non_existing_nested)
         self.assertIsNone(self.test_resource.non_existing_mapped)
+        self.assertEqual(EnumMapping.FIELD2, self.test_resource.enum_mapped)
+        self.assertEqual([EnumMapping.FIELD2, EnumMapping.FIELD3],
+                         self.test_resource.enum_mapped_list)
+        self.assertIsNone(self.test_resource.non_existing_enum_mapped)
 
     def test_missing_required(self):
         del self.json['String']
@@ -420,9 +455,11 @@ class FieldTestCase(base.TestCase):
 
     def test_mapping_missing(self):
         self.json['Nested']['Mapped'] = 'banana'
+        self.json['Enum'] = 'banana'
         self.test_resource.refresh(force=True)
 
         self.assertIsNone(self.test_resource.nested.mapped)
+        self.assertIsNone(self.test_resource.enum_mapped)
 
     def test_composite_field_as_mapping(self):
         field = self.test_resource.nested
@@ -441,6 +478,11 @@ class FieldTestCase(base.TestCase):
         self.assertRaisesRegex(KeyError, '_load', lambda: field['_load'])
         self.assertRaisesRegex(KeyError, '__init__', lambda: field['__init__'])
 
+    def test_invalid_mapping_definiton(self):
+        self.assertRaises(TypeError, resource_base.MappedField, 'Field', 42)
+        self.assertRaises(TypeError, resource_base.MappedListField,
+                          'Field', 42)
+
 
 class PartialKeyResource(resource_base.ResourceBase):
     string = resource_base.Field(
