@@ -45,10 +45,10 @@ class UpdateServiceTestCase(base.TestCase):
         self.assertFalse(self.upd_serv.http_push_uri_targets_busy)
         self.assertEqual('Update service', self.upd_serv.name)
         self.assertTrue(self.upd_serv.service_enabled)
-        self.assertEqual(res_cons.STATE_ENABLED, self.upd_serv.status.state)
-        self.assertEqual(res_cons.HEALTH_OK, self.upd_serv.status.health)
+        self.assertEqual(res_cons.State.ENABLED, self.upd_serv.status.state)
+        self.assertEqual(res_cons.Health.OK, self.upd_serv.status.health)
         self.assertEqual(
-            res_cons.HEALTH_OK,
+            res_cons.Health.OK,
             self.upd_serv.status.health_rollup)
 
     def test__parse_attributes_missing_actions(self):
@@ -70,10 +70,10 @@ class UpdateServiceTestCase(base.TestCase):
         tm = self.upd_serv.simple_update(
             image_uri='local.server/update.exe',
             targets=['/redfish/v1/UpdateService/FirmwareInventory/BMC'],
-            transfer_protocol=ups_cons.UPDATE_PROTOCOL_HTTPS)
+            transfer_protocol=ups_cons.UpdateTransferProtocolType.HTTPS)
 
         self.assertIsInstance(tm, taskmonitor.TaskMonitor)
-        self.assertEqual('/Task/545', tm.task_monitor)
+        self.assertEqual('/Task/545', tm.task_monitor_uri)
 
         self.upd_serv._conn.post.assert_called_once_with(
             '/redfish/v1/UpdateService/Actions/SimpleUpdate',
@@ -95,10 +95,11 @@ class UpdateServiceTestCase(base.TestCase):
         tm = self.upd_serv.simple_update(
             image_uri='local.server/update.exe',
             targets=['/redfish/v1/UpdateService/FirmwareInventory/BMC'],
-            transfer_protocol=ups_cons.UPDATE_PROTOCOL_HTTPS)
+            transfer_protocol=ups_cons.UpdateTransferProtocolType.HTTPS)
 
         self.assertIsInstance(tm, taskmonitor.TaskMonitor)
-        self.assertEqual('/redfish/v1/TaskService/Tasks/545', tm.task_monitor)
+        self.assertEqual('/redfish/v1/TaskService/Tasks/545',
+                         tm.task_monitor_uri)
 
         self.upd_serv._conn.post.assert_called_once_with(
             '/redfish/v1/UpdateService/Actions/SimpleUpdate',
@@ -177,7 +178,8 @@ class UpdateServiceTestCase(base.TestCase):
         software_inventory_collection_mock.assert_called_once_with(
             self.conn, '/redfish/v1/UpdateService/SoftwareInventory',
             self.upd_serv.redfish_version,
-            self.upd_serv._registries)
+            self.upd_serv._registries,
+            self.upd_serv.root)
 
     @mock.patch.object(softwareinventory, 'SoftwareInventoryCollection',
                        autospec=True)
@@ -186,7 +188,7 @@ class UpdateServiceTestCase(base.TestCase):
         software_inventory_collection_mock.assert_called_once_with(
             self.conn, '/redfish/v1/UpdateService/FirmwareInventory',
             self.upd_serv.redfish_version,
-            self.upd_serv._registries)
+            self.upd_serv._registries, self.upd_serv.root)
 
 
 class UpdateServiceNoInvTestCase(base.TestCase):
