@@ -177,7 +177,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._op('GET', path='fake/path', headers=self.headers)
         self.request.assert_called_once_with(
             'GET', 'http://foo.bar:1234/fake/path',
-            headers=self.headers, json=None, timeout=60)
+            headers=self.headers, json=None)
 
     def test_response_callback(self):
         mock_response_callback = mock.MagicMock()
@@ -191,22 +191,21 @@ class ConnectorOpTestCase(base.TestCase):
                       allow_redirects=False)
         self.request.assert_called_once_with(
             'GET', 'http://foo.bar:1234/fake/path',
-            headers=self.headers, json=None, allow_redirects=False,
-            timeout=60)
+            headers=self.headers, json=None, allow_redirects=False)
 
     def test_ok_post(self):
         self.conn._op('POST', path='fake/path', data=self.data.copy(),
                       headers=self.headers)
         self.request.assert_called_once_with(
             'POST', 'http://foo.bar:1234/fake/path',
-            json=self.data, headers=self.headers, timeout=60)
+            json=self.data, headers=self.headers)
 
     def test_ok_put(self):
         self.conn._op('PUT', path='fake/path', data=self.data.copy(),
                       headers=self.headers)
         self.request.assert_called_once_with(
             'PUT', 'http://foo.bar:1234/fake/path',
-            json=self.data, headers=self.headers, timeout=60)
+            json=self.data, headers=self.headers)
 
     def test_ok_delete(self):
         expected_headers = self.headers.copy()
@@ -214,7 +213,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._op('DELETE', path='fake/path', headers=self.headers.copy())
         self.request.assert_called_once_with(
             'DELETE', 'http://foo.bar:1234/fake/path',
-            headers=expected_headers, json=None, timeout=60)
+            headers=expected_headers, json=None)
 
     def test_ok_post_with_session(self):
         self.conn._session.headers = {}
@@ -226,7 +225,7 @@ class ConnectorOpTestCase(base.TestCase):
                       data=self.data)
         self.request.assert_called_once_with(
             'POST', 'http://foo.bar:1234/fake/path',
-            json=self.data, headers=expected_headers, timeout=60)
+            json=self.data, headers=expected_headers)
         self.assertEqual(self.conn._session.headers,
                          {'X-Auth-Token': 'asdf1234'})
 
@@ -239,7 +238,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._op('GET', path=path, headers=headers)
         self.request.assert_called_once_with(
             'GET', 'http://foo.bar:1234' + path,
-            headers=expected_headers, json=None, timeout=60)
+            headers=expected_headers, json=None)
 
     def test_odata_version_header_redfish_no_headers(self):
         path = '/redfish/v1/bar'
@@ -247,7 +246,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._op('GET', path=path)
         self.request.assert_called_once_with(
             'GET', 'http://foo.bar:1234' + path,
-            headers=expected_headers, json=None, timeout=60)
+            headers=expected_headers, json=None)
 
     def test_odata_version_header_redfish_existing_header(self):
         path = '/redfish/v1/foo'
@@ -256,7 +255,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._op('GET', path=path, headers=headers)
         self.request.assert_called_once_with(
             'GET', 'http://foo.bar:1234' + path,
-            headers=expected_headers, json=None, timeout=60)
+            headers=expected_headers, json=None)
 
     def test_timed_out_session_unable_to_create_session(self):
         self.conn._auth.can_refresh_session.return_value = False
@@ -334,46 +333,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.auth.authenticate.assert_called_once()
         self.assertEqual(response.json, third_response.json)
 
-    def test_timed_out_session_fail_after_reestablish(self):
-        self.auth._session_key = 'asdf1234'
-        self.auth.get_session_key.return_value = 'asdf1234'
-        self.conn._auth = self.auth
-        self.session = mock.Mock(spec=requests.Session)
-        self.session.auth = None
-        self.conn._session = self.session
-        self.request = self.session.request
-        first_response = mock.MagicMock()
-        first_response.status_code = http_client.FORBIDDEN
-        second_response = mock.MagicMock()
-        second_response.status_code = http_client.BAD_REQUEST
-        self.request.side_effect = [first_response, second_response]
-        self.assertRaises(exceptions.BadRequestError,
-                          self.conn._op,
-                          'POST', path='fake/path', data=self.data,
-                          headers=self.headers)
-        self.auth.refresh_session.assert_called_with()
-        self.auth.can_refresh_session.assert_called_with()
-
-    def test_timed_out_session_fail_after_reestablish_no_recursion(self):
-        self.auth._session_key = 'asdf1234'
-        self.auth.get_session_key.return_value = 'asdf1234'
-        self.conn._auth = self.auth
-        self.session = mock.Mock(spec=requests.Session)
-        self.session.auth = None
-        self.conn._session = self.session
-        self.request = self.session.request
-        first_response = mock.MagicMock()
-        first_response.status_code = http_client.FORBIDDEN
-        second_response = mock.MagicMock()
-        second_response.status_code = http_client.FORBIDDEN
-        self.request.side_effect = [first_response, second_response]
-        self.assertRaises(exceptions.AccessError,
-                          self.conn._op,
-                          'POST', path='fake/path', data=self.data,
-                          headers=self.headers)
-        self.auth.refresh_session.assert_called_with()
-        self.auth.can_refresh_session.assert_called_with()
-
     def test_connection_error(self):
         self.request.side_effect = requests.exceptions.ConnectionError
         self.assertRaises(exceptions.ConnectionError, self.conn._op, 'GET')
@@ -402,7 +361,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertEqual(http_client.BAD_REQUEST, exc.status_code)
         self.assertIsNotNone(exc.body)
         self.assertIn('body submitted was malformed JSON', exc.detail)
-        self.assertEqual(len(exc.extended_info), 3, exc.extended_info)
 
     def test_known_http_error_nonlist_ext_info(self):
         self.request.return_value.status_code =\
@@ -418,8 +376,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertEqual(http_client.UNSUPPORTED_MEDIA_TYPE, exc.status_code)
         self.assertIsNotNone(exc.body)
         self.assertIn('See Resolution for information', exc.detail)
-        self.assertIn('unsupported media type',
-                      exc.extended_info['Resolution'])
 
     @mock.patch('time.sleep', autospec=True)
     def test_not_found_error(self, mock_sleep):
@@ -448,42 +404,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertEqual(10, mock_sleep.call_count)
         self.assertEqual(11, self.request.call_count)
 
-    @mock.patch('time.sleep', autospec=True)
-    def test_op_retry_on_server_500_sys518(self, mock_sleep):
-        response_info = {"error": {"@Message.ExtendedInfo": [
-            {'MessageId': 'IDRAC.2.7.SYS518'}]}}
-        mock_error = mock.Mock()
-        mock_error.status_code = 500
-        mock_error.json.return_value = response_info
-        self.request.return_value.status_code = (
-            http_client.INTERNAL_SERVER_ERROR)
-        self.request.return_value.json.side_effect =\
-            exceptions.ServerSideError(
-                method='DELETE', url='http://foo.bar', response=mock_error)
-
-        self.assertRaises(exceptions.ServerSideError, self.conn._op, 'DELETE',
-                          'http://foo.bar')
-        self.assertEqual(10, mock_sleep.call_count)
-        self.assertEqual(11, self.request.call_count)
-
-    @mock.patch('time.sleep', autospec=True)
-    def test_op_retry_on_server_500_other_than_sys518(self, mock_sleep):
-        response_info = {"error": {"@Message.ExtendedInfo": [
-            {'MessageId': 'IDRAC.2.7.SYS999'}]}}
-        mock_error = mock.Mock()
-        mock_error.status_code = 500
-        mock_error.json.return_value = response_info
-        self.request.return_value.status_code = (
-            http_client.INTERNAL_SERVER_ERROR)
-        self.request.return_value.json.side_effect =\
-            exceptions.ServerSideError(
-                method='DELETE', url='http://foo.bar', response=mock_error)
-
-        self.assertRaises(exceptions.ServerSideError, self.conn._op, 'DELETE',
-                          'http://foo.bar')
-        self.assertEqual(0, mock_sleep.call_count)
-        self.assertEqual(1, self.request.call_count)
-
     def test_access_error(self):
         self.conn._auth = None
 
@@ -583,7 +503,7 @@ class ConnectorOpTestCase(base.TestCase):
             'this is expected prior to authentication', 'HTTP GET '
             'http://redfish/v1/SessionService returned code '
             '%s. unknown error Extended information: '
-            'None' % http_client.FORBIDDEN)
+            'none' % http_client.FORBIDDEN)
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
 
     def test_blocking_no_location_header(self):
@@ -619,10 +539,10 @@ class ConnectorOpTestCase(base.TestCase):
     def test_access_error_basic_auth(self, mock_log):
         self.conn._auth.can_refresh_session.return_value = False
         self.conn._session.auth = ('foo', 'bar')
-        self.request.return_value.status_code = 403
+        self.request.return_value.status_code = http_client.FORBIDDEN
         mock_response = mock.Mock()
         mock_response.json.side_effect = ValueError('no json')
-        mock_response.status_code = 403
+        mock_response.status_code = http_client.FORBIDDEN
         self.request.return_value.json.side_effect = ValueError('no json')
 
         with self.assertRaisesRegex(exceptions.AccessError,
@@ -631,13 +551,12 @@ class ConnectorOpTestCase(base.TestCase):
         exc = cm.exception
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
         self.conn._auth.authenticate.assert_not_called()
-        error_msg = (f'HTTP GET http://redfish/v1/SessionService '
-                     f'returned code {exc.status_code}. unknown error '
-                     f'Extended information: None')
         mock_log.assert_called_once_with(
             "We have encountered an AccessError when using 'basic' "
             "authentication. %(err)s",
-            {'err': error_msg}
+            {'err': 'HTTP GET http://redfish/v1/SessionService '
+                    'returned code HTTPStatus.FORBIDDEN. unknown error '
+                    'Extended information: none'}
         )
 
     def test__op_raises_connection_error(self):
